@@ -1,3 +1,4 @@
+#![allow(clippy::redundant_closure)]
 use {
     solana_cli::{
         cli::{process_command, request_and_confirm_airdrop, CliCommand, CliConfig},
@@ -10,7 +11,6 @@ use {
         nonce_utils,
         rpc_client::RpcClient,
     },
-    solana_core::test_validator::TestValidator,
     solana_faucet::faucet::run_local_faucet,
     solana_sdk::{
         commitment_config::CommitmentConfig,
@@ -20,6 +20,7 @@ use {
         stake,
     },
     solana_streamer::socket::SocketAddrSpace,
+    solana_test_validator::TestValidator,
 };
 
 #[test]
@@ -108,7 +109,7 @@ fn test_transfer() {
     check_recent_balance(50, &rpc_client, &offline_pubkey);
 
     // Offline transfer
-    let (blockhash, _) = rpc_client.get_recent_blockhash().unwrap();
+    let blockhash = rpc_client.get_latest_blockhash().unwrap();
     offline.command = CliCommand::Transfer {
         amount: SpendAmount::Some(10),
         to: recipient_pubkey,
@@ -320,7 +321,7 @@ fn test_transfer_multisession_signing() {
 
     check_ready(&rpc_client);
 
-    let (blockhash, _) = rpc_client.get_recent_blockhash().unwrap();
+    let blockhash = rpc_client.get_latest_blockhash().unwrap();
 
     // Offline fee-payer signs first
     let mut fee_payer_config = CliConfig::recent_for_tests();
